``` yaml
cert_requests:
- identifier: acn
  ledger_id: fetchai
  not_after: '2024-01-01'
  not_before: '2023-01-01'
  public_key: fetchai
  message_format: '{public_key}'
  save_path: .certs/conn_cert.txt
```